/*
    This file creates a panel dataset based on the GCFS 2002 - 2010
    which can be used to produce descriptive statistics for Cocobod.

    The structure if the following
	
	0. PRELIMINARIES
	1. 2008 DATA
		1.0 restrict to panel villages
		1.1 drop false interviews
		1.3  Household-level production data (output, inputs)
		1.4  Plot-level data (farm sizes, tree types)
			1.4.0 obtaining key variables
			1.4.1 coversion to hectares
			1.4.2 collapsing to farmer level
	2. 2006 DATA
		2.1  Household-level production data (output, inputs)
		2.2  Plot-level data (farm sizes, tree types)
	3. 2004 DATA
		3.1  Plot-level data (farm sizes, tree types)
		3.2  Household-level production data (output, inputs)
	4. 2002 DATA
		4.1 Plot-level data (farm sizes, tree types)
		4.2 Household level production data (output, inputs)
	5. DATA PREPARATION
		5.1 derived variables of interest
		5.2 time setting the  data
	
*/



/*  0.  PRELIMINARIES  */

	*   0.1  Stata preliminaries
		clear
		clear matrix
		set more off
		set mem 30m

	*   0.2  Declaring file locations
		cd "C:\Users\econfjt\Documents\stataprogs\Ghana_Cocoa_Panel_Survey\Ghana_Cocoa_Panel_Public_April_2013\temp"
		*global root "D:\stataprogs\Ghana_Cocoa_Panel_Survey\AZ_Drop_Box_June_2012\public"
		global root "C:\Users\econfjt\Documents\stataprogs\Ghana_Cocoa_Panel_Survey\Ghana_Cocoa_Panel_Public_April_2013"
		*global root "D:\stataprogs\Ghana_Cocoa_Panel_Survey\AZ_Drop_Box_June_2012\public"
		
		global gcfs02 "$root\data\2002"
		global gcfs04 "$root\data\2004"
		global gcfs06 "$root\data\2006"
		global gcfs08 "$root\data\2008"
		global gcfs10 "$root\data\2010"
		global prompt10 "$root\data\2010\prompt" // source of village types
		*global dropdata "C:\Users\csae.offsite\Desktop\gcfs\public\data"
		*global public "$root\public" // Directory for storing final (and working) data
		global data "$root\output"
		
	*  0.3.  What to do?  
		global do02 "on" 
		global do04 "on" 
		global do06 "on" 
		global do08 "on" 
		global do10 "on" 
		
		global dodropbox "off" // {off | on} .  Switch to "on" to automatically save results to dropbox.

	*  0.4  Declaring temporary filenames (for use during merger process)
		tempfile plots02 plots04 plots06 plots08 plots10
		tempfile main02 main04 main06 main08 main10



	*  0.5  defining programs for data cleaning
	capture program drop mycode
	program define mycode, rclass
		version 10
		syntax varname ,  Label(string)
		/*
			Description:  this program encodes and replaces variables using a variable label.  a shortcut for the encode command. imposes -noextend- option.
		*/

		tempvar vv
		*  replace `varlist' = upper(`varlist')
		encode `varlist', label(`label') noextend generate(`vv')
		drop `varlist'
		rename `vv' `varlist'

	end
	
	
	
****************************************************************************	
/*  2010 DATA  */
****************************************************************************
if "$do10" == "on" {
	*  Plot-level data
		use "$gcfs10\plots"
		
		*  Restrict attention to cocoa farms	
			keep if cocoafarm == 1 // this singles out plots with cocoa grown
	
			ge totland = s3q1a_ha
			ge cocoaland = s3q9a_ha // total land devoted to cocoa // 
			
		*  Collapsing to farmer level
		
			ge plotcount = 1
			collapse (sum) hybrid_area hafullprod cocoaland totland plotcount, by(s0far)

		*  Variables defined at the farmer level
			ge hybridlandshare = hybrid_area / cocoaland
			label variable hybridlandshare "actual share hybrid trees"
			
			label variable hafullprod "`hafullprod'"
			
			ge lnhaprod = ln(hafullprod)
			label variable lnhaprod "ln coooa land in full production, ha."
		
		sort s0far
		save `plots10', replace

		
	*  Household-level data
		use "$gcfs10/main"
		
		*  Exclude Abrabopa sample
		
			tempvar vtypes
			merge m:1 s0vil using "$prompt10\village types - abrabopa vs panel.dta", gen(`vtypes') // a village-level dataset defining the sample
			tab `vtypes' sample
	
			drop if `vtypes' == 2 // one (Abrabopa!) village has not been visited yet.
			drop if sample == 2
			drop sample 
			
		*  Exclude individuals not interviewed in the 2010 round.
			drop if (s0farstillfarm == 0 ) /// (potentially) still present, but not farming.
				| (s0farispresent == 0 & ( s0farnotpresentwhy == "refused" | s0farnotpresentwhy == "deceased" | s0farnotpresentwhy == "dead" |  s0farnotpresentwhy == "migrated (permanently)"   )) /// conditions for no re-interview sought
				| s0standinyn == 0 /// or there is no stand in
				| s0far == 999999 // or the interview is a test case/not real data.
		
		*  Identifiers // TODO : move cleanup of regions upstream to general cleaning routine for GCFS 2010.  
			ge year = 2010
			replace s0rgn = 3 if s0vil == 324  // one farmer is mistakenly assigned to Eastern Region.
			replace s0rgn = 2 if s0vil == 212 | s0vil == 215 | s0vil == 216
		

		*  Household-level production data (output, inputs, marketing) 
			*  Output
				ge kg_cocoa = cocoa09 // this variable has already been cleaned
				drop cocoa??
			
			*  Inputs:  renaming for compatibility with the panel.
				rename fert_50kg fertilizer_50kg
				rename insect_yn insecticide 
				label variable insecticide "used insecticide"
				rename spray_yn spraymch
				label variable spraymch "used spray machine"
				
			*  Marketing
				label variable s8bq1 "Licensed Buying Companies present in village" 

		*  Merging with plots data, and saving hh-level data
			keep s0far s0rgn s0vil s0nam year ///  identifiers and  controls
			kg_cocoa ///  derived from s2aq19a, with unified units and cross-checked
			fert_yn fertilizer_50kg insecticide spraymch ///  select non-labor inputs
			hh_days hired_days paid_days nnoboa_days /// labor inputs (measured in days)
			certify* ///  certification questions. 
			s8bq1 // LBCs 
			
			merge 1:1 s0far using `plots10', gen(_mplots10)
			
			drop if _mplots10 == 2
			drop _mplots10
		
			sort s0far
			save `main10', replace	
}


****************************************************************************
/*  2008 DATA */
****************************************************************************
if "$do08" == "on" {
	*  1.0 restrict to panel villages

		*  Use 2006 data to identify panel villages
			tempfile panel06  
			
			use "$gcfs06\main"
			
			tostring s0far, g(_s0far)
			ge vcode = substr(_s0far, 1,3)
			destring vcode, replace
			egen _vcode = mode(vcode), by(s0vil)
			replace vcode = _vcode
			drop _*
			
			sort s0far
			save `panel06'
		
		*  Keep only panel villages
			use "$gcfs08\main"
			
			tostring s0far, g(_s0far)
			ge v_id = substr(_s0far, 1,3)
			destring v_id, replace
			
			
			ge vcode = s0vil
			label values vcode s0vil
			
			
			tempvar vtypes
			merge m:1 s0vil using "$prompt10\village types - abrabopa vs panel.dta", gen(`vtypes') // a village-level dataset defining the sample
			tab `vtypes' sample
	
			drop if `vtypes' == 2 // one (Abrabopa!) village has not been visited yet.
			drop if sample == 2
			drop sample 

			
			
			sort s0far
			merge s0far using `panel06', _merge(_old)
			
			ge oxvisit = (_old == 1 | _old == 3)
			label variable oxvisit "individual surveyed in 2008"
			
			ge panel = (_old ==2 | _old == 3)
			label variable panel "individual is panel member"
			 
			
			egen villvisit = max(oxvisit), by(vcode)
			label variable villvisit "village visited in 2008, to date"
			egen villpanel = max(panel), by(vcode)
			label variable villpanel "village contains panel members"
			egen villtot06 = total(panel), by(vcode)
			label variable villtot06 "total 2006 panel members in village"
			egen villtot08= total(oxvisit), by(vcode)
			label variable villtot08 "total village individuals interviewed in 2008"
			
			keep if villpanel == 1 & villvisit == 1
			
			drop _old
			
		
		* 1.1 drop false interviews
		
			ge migrated_or_died = 1 if   s0farnotpresentwhy == "migrated (permanently)" | ///
			s0farnotpresentwhy == "migrated (seasonally)" | ///
			s0farnotpresentwhy == "migrated seasonally" | ///
			s0farnotpresentwhy == "deceased"
			replace migrated_or_died = 0 if migrated_or_died == .
			
			ge nostandin = 1 if  s0standinyn == "N"
			replace nostandin = 0 if nostandin == .
			
			ge nococoa = 1 if  s0farstillfarm == "N"
			replace nococoa = 0 if nococoa == .
			
			ge noaddition = 1 if  s0newaddition == "N"
			replace noaddition = 0 if noaddition == .
			
			ge  flag = migrated_or_died + nostandin + nococoa 
			replace flag = 1 if flag > 1
			drop if flag == 1
			drop if flag == .
			
			keep s0far 
			sort s0far 
			save "$data\panel", replace
			

	*  1.3  Household-level production data (output, inputs)
		use "$gcfs08\main"
		ge year = 2008
		*  Output
			rename s2aq19a kg_cocoa
			replace kg_cocoa = kg_cocoa*62.5 if s2aq19b == "maxibags"
			
			
		*  Non-labor inputs : renaming for consistency with panel
				rename fert_50kg fertilizer_50kg // for consistency
				rename insect_yn insecticide // for consistency
				rename spray_yn spraymch 
			
		*  Labor inputs -- already compiled in the source file. 
			
		*  Identifiers
			replace s0rgn = "1" if s0rgn == "Ashanti"
			replace s0rgn = "2" if s0rgn == "Brong Ahafo"
			replace s0rgn = "3" if s0rgn == "Western"
			replace s0rgn = "" if s0rgn == "Central" | s0rgn == "Eastern"
			destring s0rgn, replace
		
		*  Saving individual-level data for 2008
			keep s0far s0rgn s0vil s0nam year ///  identifiers and  controls
				kg_cocoa ///  derived from s2aq19a, with unified units and cross-checked
				fert_yn fertilizer_50kg insecticide spraymch ///  select non-labor inputs
				hh_days hired_days paid_days nnoboa_days /// labor inputs (measured in days)
			
			
			sort s0far
			merge s0far using "$data\panel", _merge(panelmerge)
			drop if panelmerge != 3
			
			sort s0far year
			save "$data\panel", replace
	


	*  1.4  Plot-level data (farm sizes, tree types)

		* 1.4.0 obtain key variables
		
		use "$gcfs08\plots"
		
		*  Define and keep cocoa farms onlly
		ge cocoafarm = 1 if s3q8_1 == "Cocoa" | s3q8_2 == "Cocoa" | s3q8_3 == "Cocoa"
		
		keep if cocoafarm == 1 // this singles out plots with cocoa grown
		
		*  Farm values
			rename s3q5 totprice // if the plot were to be sold, how much would it be worth
			replace totprice = totprice/10000 if s3value_unit == "Old Cedis"
		 
		*  Matrix of tree types and ages
			* rename s3q14_1 treetype1 (Romain: treetype1 already exists)
			* rename s3q14_1b tree1area (same)
			* rename s3q14_1_0to4 tree104 // area of type 1 trees from 0 to 4 years old
			* rename s3q14_1_5to9 tree159 // area of type 1 trees from 5 to 9 years old
			* rename s3q14_1_10to19 tree11019 // area of type 1 trees from 10 to 19 years old
			* rename s3q14_1_20plus tree120 // area of type 1 trees older than 20 years
			
			* rename s3q14_2 treetype2
			* rename s3q14_2b tree2area 
			* rename s3q14_2_0to4 tree204
			* rename s3q14_2_5to9 tree259
			* rename s3q14_2_10to19 tree21019
			* rename s3q14_2_20plus tree220
			
			* rename s3q14_3 treetype3
			* rename s3q14_3b tree3area
			* rename s3q14_3_0to4 tree304
			* rename s3q14_3_5to9 tree359
			* rename s3q14_3_10to19 tree31019
			* rename s3q14_3_20plus tree320
			
			replace tree104 = 0 if tree104 == .
			replace tree204 = 0 if tree204 == .
			replace tree304 = 0 if tree304 == .
			replace tree120 = 0 if tree120 == .
			replace tree220 = 0 if tree220 == .
			replace tree320 = 0 if tree320 == .
			replace tree159 = 0 if tree159 == .
			replace tree259 = 0 if tree259 == .
			replace tree359 = 0 if tree359 == .
			replace tree11019 = 0 if tree11019 == .
			replace tree21019 = 0 if tree21019 == .
			replace tree31019 = 0 if tree31019 == .
		
		*  Prepping aggregate measures of farm size
			rename s3q1b cocoa_unit // unit of measurement for all area variable specific to this plot
			rename s3q1a_ha totland // total land 

			label variable totland "total farm land, ha"
		
			rename s3q9a_ha cocoaland // total land devoted to cocoa
			label variable cocoaland "cocoa land, ha"
		
		*  Fraction in full production and by tree type
			*  First, convert the area devoted to young/old tree type, and the type-specific aggregates, into hectares.  
				foreach v of varlist tree1area tree2area tree3area tree?04 tree?59 tree?1019 tree?20 {
					replace `v' = `v' / 2.471 if cocoa_unit == 1
					replace `v' = `v' * 0.68 / 2.471 if cocoa_unit == 2
					replace `v' = `v' / (9 * 2.471) if cocoa_unit == 3
				}
			*  Now, subtract the young and the old to get productive acreage
				egen notfull = rowtotal(tree?04 tree?20)
				egen anyage = rowtotal(tree?04 tree?59 tree?1019 tree?20 )
				ge fracnotfull = notfull / anyage
				replace fracnotfull = 0 if fracnotfull == . // assuming all productive for the 12 instances where these data are all missing.
				
	
				ge hafullprod =  cocoaland * (1 - fracnotfull)
				label variable hafullprod "cocoa land in full production, ha."

			*  And compile totals by type.
				* ge agric_area = tree1area if treetype1 == "AGRIC" | treetype1 == "AGIC" ///
				* | treetype1 == "agric "
				gen agric_area = . //Romain: functionally equivalent to previous line
				* replace agric_area = tree2area if treetype2 == "AGRIC" ///
				* | treetype2 == "agric "
				replace agric_area = 0 if agric_area == .
				
				ge amazon_area = tree1area if treetype1 == 1 //"Amazon"
				replace amazon_area = tree2area if treetype2 == 1 //"Amazon" 
				replace amazon_area = tree3area if treetype3 == 1 //"Amazon"
				replace amazon_area = 0 if amazon_area == .
				
				ge h_area = tree1area if treetype1 == 2 //"Hybrid" 
				replace h_area = tree2area if treetype2 == 2 //"Hybrid"
				replace h_area = tree3area if treetype3 == 2 //"Hybrid"
				replace h_area = 0 if h_area == .
				ge hybrid_area = h_area + agric_area
				label variable hybrid_area "area cultivated with hybird trees, ha"
				
				ge tq_area = tree1area if treetype1 == 3 //"Tettah Quashie (local)"
				replace tq_area = tree2area if treetype2 == 3 //"Tettah Quashie (local)"
				replace tq_area = tree3area if treetype3 == 3 //"Tettah Quashie (local)"
				replace tq_area = 0 if tq_area == .
				
				ge hybridsland = hybrid_area / (hybrid_area + tq_area + amazon_area) * cocoaland
				label variable hybridsland "land planted with hybrid trees, ha."
				
		
		*  1.4.2 collapsing to farmer level
		
			local hafullprod : variable label hafullprod
			
			ge plotcount = 1
			
			collapse (sum) hybridsland hafullprod cocoaland totland totprice plotcount, by(s0far)
			ge hybridlandshare = hybridsland/cocoaland
			label variable hybridlandshare "actual share hybrid trees"
			
			label variable hafullprod "`hafullprod'"
			
			ge lnhaprod = ln(hafullprod)
			label variable lnhaprod "ln coooa land in full production, ha."
			
			ge priceha= totprice/totland
			label variable priceha "land price, c/ha"
		

	*  Merge & create panel
		*  ID fix
			replace s0far = 326483 if s0far == 324430 // & s0nam == "Philemon Kyei"

		sort s0far 
		merge s0far using "$data\panel", _merge(_m08plots)
		drop if _m08plots == 1
		sort s0far year
		save "$data\panel", replace

		
		*  Append 2010 interviews
			append using `main10'
			sort s0far year
			save "$data\panel", replace

}


			

****************************************************************************
/*  2006 DATA */
****************************************************************************
if "$do06" == "on" {
	
	*  2.1  Household-level production data (output, inputs)
		
		
		use "$gcfs06\main"
		
		*  Non-labor inputs
			rename s4bq1a fert_yn
			replace fert_yn = "1" if fert_yn == "Yes"
			replace fert_yn = "0" if fert_yn == "No"
			destring fert_yn, replace
			
			rename s4bq2aa fertilizer_50kg
			rename s4bq2ba fert_unit
			replace fertilizer_50kg = fertilizer_50kg / 50 if fert_unit == "Kilos"
			replace fertilizer_50kg = fertilizer_50kg *2 if fert_unit == "Boxes"
			replace fertilizer_50kg = 0 if fertilizer_50kg == . & fert_yn == 0
			
			
			rename s4bq1b insecticide
			rename s4bq1c spraymch
			
			replace insecticide = "1" if insecticide == "Yes"
			replace insecticide = "0" if insecticide == "No"
			destring insecticide, replace
			replace spraymch = "1" if spraymch == "Yes"
			replace spraymch = "0" if spraymch == "No"
			destring spraymch, replace

	
		*  HOUSEHOLD LABOR INPUTS
			/*
				in 2006, there are 4 types of hh labor input:
				men, women, children, and young adults.
				
				Each gets a leading yes/no question, 
				then is asked about contribution by task,
				then about contribution to each task on each farm.
				
				- types {a,b,c,d}
				- tasks: {a, b, c, d, e}
				- plots: _1, _2, ... , _5
			*/
			label define yesno 1 "Yes" 0 "No" , modify

			replace s3baqb2e_2 = "30" if s3baqb2e_2 == "0=30"
			destring s3baqb2e_2, replace

			tokenize men women children youngadults
			*  looping over hh members: men, women, children, young adults:
			foreach m in a b c d {
				*  encoding the aggregate answer: were there any of type m on the farm?
					replace `1' = "" if `1' == "."
					mycode `1', l(yesno)
				foreach t in a b c d e { // looping over tasks on the farm
					replace s4aq3`m'1`t' = 0 if `1' == 0 & s4aq3`m'1`t' == . // # people
					replace s4aq3`m'2`t' = 0 if s4aq3`m'2`t' == . & ( `1' == 0 | s4aq3`m'1`t' == 0 )
					foreach p in 1 2 3 4 5 {
						
						
						replace s3baq`m'1`t'_`p' = 0 if s3baq`m'1`t'_`p' == . & s4aq3`m'1`t' == 0 // convert plot-level persons to zero if missing and aggregate days == 0.  
						replace s3baq`m'2`t'_`p' = 0 if s3baq`m'2`t'_`p' == . & s4aq3`m'2`t' == 0 // convert plot-level days to zero if missing and aggregate days == 0 
					}
					ge _`1'`t'days_ = s4aq3`m'1`t' * s4aq3`m'2`t'
					
				}
				*  egen `1'_days = rowtotal( _`1'*days_  )
				ge `1'_days = s4aq3`m'1a * s4aq3`m'2a + s4aq3`m'1b * s4aq3`m'2b + s4aq3`m'1c*s4aq3`m'2c + s4aq3`m'1d*s4aq3`m'2d + s4aq3`m'1e*s4aq3`m'2e // this would be a more conservative approach:  would not impose zeros for missing categories.  
				drop _`1'*days_
				mac shift // move on to next type
			}
			
			ge hh_days = men_days + women_days + children_days + youngadults_days
			


	*  HIRED LABOR INPUTS
		label define yesno 1 "Yes" 0 "No" , modify
		foreach v of varlist employcontractlabourday employcontractlabourtask employannuallabour employnnoboalabour {
				replace `v' = "" if `v' == "."
				mycode `v', l(yesno)
			}
			
		*  this small subsection should be redundant.
			foreach var of varlist s4aq7a* s3bbqa* {
				replace `var' = 0 if `var' ==. & ( (employcontractlabourday== 0 & employcontractlabourtask== 0 ))
			}
			foreach var of varlist s4aq7a*day s3bbqa*day* {
				replace `var' = 0 if `var' ==. & employcontractlabourday==0 
			}
			foreach var of varlist s4aq7a*task s3bbqa*task* {
				replace `var' = 0 if `var' ==. & employcontractlabourtask== 0 
			}
			foreach var of varlist s4aq7b* s3bbqb* {
				replace `var' = 0 if `var' ==. & (employannuallabour== 0 )
			}
			foreach var of varlist s4aq7c* s3bbqc* {
				replace `var' = 0 if `var' ==. & ( employnnoboalabour== 0 )
			}

		
		*  Paid labor types:

			* contract labor : by day, by task

				foreach i in a {
					foreach k in day task {
						local `k'expr " 0 "
						foreach t in a b c d e{
							replace s4aq7`i'1`t'`k' = 0 if s4aq7`i'1`t'`k' == . & employcontractlabour`k' == 0
							replace s4aq7`i'2`t'`k' =0 if s4aq7`i'1`t'`k' ==0 & s4aq7`i'2`t'`k' ==.
							replace s4aq7`i'3`t'`k' =0 if s4aq7`i'2`t'`k' ==0 & s4aq7`i'3`t'`k' ==.
							foreach p in 1 2 3 4 5 {
								replace s3bbq`i'1`t'`k'_`p'=0 if (s4aq7`i'1`t'`k' ==0 | s4aq7`i'2`t'`k' ==0) & s3bbq`i'1`t'`k'_`p'==.
								replace s3bbq`i'2`t'`k'_`p'=0 if s3bbq`i'1`t'`k'_`p'==0 & s3bbq`i'2`t'`k'_`p'==.
							}
							local `k'expr "``k'expr' + s4aq7`i'1`t'`k' * s4aq7`i'2`t'`k'" // for use in sums below.
						}
						
					}
				}
				
				di "`dayexpr'"
				di "`taskexpr'"
				ge cday_days = `dayexpr'
				ge ctask_days = `taskexpr'
		
		* annual and nnoboa labour
			tokenize annual nnoboa
			local b annual
			local c nnoboa
			foreach i in b c {
				foreach t in a b c d e{
					replace s4aq7`i'1`t' = 0 if s4aq7`i'1`t' == . & employ``i''labour == 0
					replace s4aq7`i'2`t' =0 if s4aq7`i'1`t' ==0 & s4aq7`i'2`t' ==.
					replace s4aq7`i'3`t' =0 if s4aq7`i'2`t' ==0 & s4aq7`i'3`t' ==.
					foreach p in 1 2 3 4 5 {
					    replace s3bbq`i'1`t'_`p'=0 if (s4aq7`i'1`t' ==0 | s4aq7`i'2`t' ==0 | employ`1'labour == 0) & s3bbq`i'1`t'_`p'==.
					    replace s3bbq`i'2`t'_`p'=0 if s3bbq`i'1`t'_`p'==0 & s3bbq`i'2`t'_`p'==.
					}
				}
				mac shift
			}
			
		ge annual_days = s4aq7b1a * s4aq7b2a + s4aq7b1b * s4aq7b2b + s4aq7b1c * s4aq7b2c + s4aq7b1d*s4aq7b2d + s4aq7b1e*s4aq7b2e
		ge nnoboa_days = s4aq7c1a * s4aq7c2a + s4aq7c1b*s4aq7c2b + s4aq7c1c*s4aq7c2c + s4aq7c1d*s4aq7c2d + s4aq7c1e * s4aq7c2e
		
		ge paid_days = cday_days + ctask_days + annual_days
		ge hired_days = paid_days + nnoboa_days			

	
		*  Keeping required variables
		keep s0far s0rgn s0vil year s0nam ///  identifiers and  controls
			kg_cocoa ///  derived from s2aq19a, with unified units and cross-checked
			fert_yn fertilizer_50kg insecticide spraymch ///  select non-labor inputs
			hh_days hired_days paid_days nnoboa_days /// labor inputs (measured in days)
		
		capture ge year
		sort s0far year
		save `main06', replace
	
	
	*  2.2  Plot-level data (farm sizes, tree types)
	
		
		use "$gcfs06\plots"
		
			keep if cocoafarm == 1 // not all plots have cocoa grown.  This singles out the relevant ones.
		
			*  Calculating alternative land measures -- cleaning data for questions s3q11-q13
			foreach v of varlist s3q11 s3q12 s3q13 {
				split `v', p("/") destring
				drop `v'
				ge `v' = `v'1 / `v'2
				replace `v' = `v'1 if `v' == .
			}
			tempvar tottrees 
			egen `tottrees' = rowtotal(s3q11 s3q12 s3q13 )   
			foreach v of varlist s3q11 s3q12 s3q13 {
				replace `v' = `v' / `tottrees' if `tottrees' != .
			}
			ge hafullprod = s3q12*s3q9a_ha
			label variable hafullprod "cocoa land in full production, ha."
		
			*  Tree types cleanup:
			drop `tottrees'
			egen tottrees = rowtotal(s3q14_?b) // note: make tempfile
			
			label define cocoatypes ///
				0 "No cocoa is currently grown on this farm" ///
				1 "Tettah Quashie (local)" ///
				2 "Amazon" ///
				3 "Hybrid" ///
				, modify
		
			ge amazon = 0
			ge tq = 0
			ge hybrid = 0
			foreach v in amazon tq hybrid {
				label variable `v' "share of land planted with `v'"
			}
		
			foreach v in s3q14_1 s3q14_2 s3q14_3 {
				replace `v' = "Hybrid" if `v' == "AGRIC" | `v' == "AGIC"
				replace `v' = "Hybrid" if `v' == "HYBRID" | `v' == "agric"
				replace `v' = "Amazon" if `v' == "AMAZON" 
				replace `v' = "Tettah Quashie (local)" if `v' == "TETTAH QUASHIE (LOCAL)"
				replace `v' = "No cocoa is currently grown on this farm" ///
					if `v' == upper("No cocoa is currently grown on this farm") ///
					| `v' == "THE FARM HAS BEEN DESTROYED BY DESEASES" ///
					| `v' == "the farm has been destroyed by deseases" 
				replace `v' = "" if `v' == "Only one type of cocoa is grown on the farm." ///
					| `v' == "Only two types of cocoa are grown on this farm." ///
					| `v' == "."
				encode `v', l(cocoatypes) g(_`v') noextend
				drop `v' 
				rename _`v' `v'
			
				replace tq = tq + `v'b if `v'==1
				replace amazon = amazon + `v'b if `v'==2
				replace hybrid = hybrid + `v'b if `v'==3
			}
			ge hybridsland = s3q9a_ha * hybrid / (hybrid + tq + amazon)
			label variable hybridsland "land planted with hybrid trees, ha."
		
		
			*  collapsing to farmer level
			local hafullprod : variable label hafullprod
			local s3q9a_ha : variable label s3q9a_ha
			local s3q1a_ha : variable label s3q1a_ha
		
			ge plotcount = 1
		
			collapse (sum) hybridsland hafullprod cocoaland=s3q9a_ha totland=s3q1a_ha totprice=s3q5 plotcount, by(s0far)
			ge hybridlandshare =hybridsland/cocoaland
			label variable hybridlandshare "actual share hybrid trees"
		
			*  Generating and labelling farmer-level variables
			label variable hafullprod "`hafullprod'"
			ge lnhaprod = ln(hafullprod)
			label variable lnhaprod "ln coooa land in full production, ha."
			label variable totland "`s3q1a_ha'"
			label variable cocoaland "`s3q9a_ha'"
		
		
			ge priceha=totprice/totland
			label variable priceha "land price, c/ha"
		
		
			sort s0far 
			merge s0far using `main06', _merge(_m06main)
			capture drop year
			ge year = 2006
		
	*  Merge to panel
	
		sort s0far year
		merge s0far year using "$data\panel", _merge(_m06plots)
		sort s0far year
		save "$data\panel", replace
}


****************************************************************************
/*  2004 DATA */
****************************************************************************
if "$do04" == "on" {
	
	*  3.1  Plot-level data (farm sizes, tree types)
	
	
	*  [Francis: note I will merge the household level data into the plots data to minimize the use of temporary files, etc.]
	use "$gcfs04\plots04"
	
		capture gen cocoafarm=1 if (s3q8a==4 | s3q8b==4 | s3q8c==4 | s3q8d==4 | s3q8e==4) | (s3bq1a~=. & s3bq1a>0)
		keep if cocoafarm == 1 // not all plots have cocoa grown.  This singles out the relevant ones.
	
		*  Calculating alternative land measures -- cleaning data for questions s3q11-q13
		foreach v of varlist s3q11 s3q12 s3q13 {
			split `v', p("/" "[" ) destring
			drop `v'
			ge `v' = `v'1 / `v'2
			replace `v' = `v'1 if `v' == .
		}
		tempvar tottrees 
		egen `tottrees' = rowtotal(s3q11 s3q12 s3q13 )   
		foreach v of varlist s3q11 s3q12 s3q13 {
			replace `v' = `v' / `tottrees' if `tottrees' != .
		}
		ge hafullprod = s3q12*s3q9a_ha // TODO : add full plot size if s3q12 == . ?  i.e. replace hafullprod = s3q9a_ha if hafullprod == . (?)
		label variable hafullprod "cocoa land in full production, ha."

		*  Hybrid trees (2004)  [note already encoded]
		ge amazon = 0
		ge tq = 0
		ge hybrid = 0
		foreach v in amazon tq hybrid {
			label variable `v' "share of land planted with `v'"
		}
		foreach v in s3q14a s3q14b s3q14c {
			replace tq = tq + `v'2 if `v'==1
			replace amazon = amazon + `v'2 if `v'==2
			replace hybrid = hybrid + `v'2 if `v'==3
		}
		ge hybridsland = s3q9a_ha * hybrid / (hybrid + tq + amazon)
		label variable hybridsland "land planted with hybrid trees, ha."

	
		*  Collapsing 
		ge plotcount = 1 
	
		collapse (sum) plotcount hafullprod hybridsland cocoaland=s3q9a_ha totland=s3q1a_ha totprice=s3q5, by(s0far)

		ge hybridlandshare =hybridsland/cocoaland
		label variable hybridlandshare "actual share hybrid trees"
		ge priceha=totprice/totland
		label variable priceha "land price, c/ha"
		ge lnhaprod = ln(hafullprod)

	
	
	*  3.2  Household-level production data (output, inputs)
	
	
	sort s0far
	merge s0far using "$gcfs04\gcfs04" ///
		, _merge(_m04plots) ///
		keep( s0rgn s0vil kg_cocoa fert_yn fertilizer_50kg s4bq1b spraymch hh_days hired_days paid_days nnoboa_days )
	
	rename s4bq1b insecticide
	
	capture ge year = 2004
	sort s0far year
	
	*  Merging 2004 with 2006 data
	merge s0far year using "$data\panel.dta", _merge(_m04)
	sort s0far year
	save "$data\panel.dta", replace
	
	
****************************************************************************
/*  2002 DATA */
****************************************************************************
if "$do02" == "on" {
	
	*  4.1 Plot-level data (farm sizes, tree types)
	
	
	use "$gcfs02/plots02"
	
		gen cocoafarm=1 if (s3q8a==4 | s3q8b==4 | s3q8c==4 | s3q8d==4 | s3q8e==4) | (s3q9a~=. & s3q9a>0)
		keep if cocoafarm == 1 // not all plots have cocoa grown.  This singles out the relevant ones.
	
	
		*  Calculating alternative land measures -- cleaning data for questions s3q11-q13
		foreach v in s3q11 s3q12 s3q13 {
			ge `v' = `v'n / `v'd
			replace `v' = `v'n if `v' == .
		}

		/*  skipping this -- appears to be a mistake.  these variables are ALREADY expressed as fractions.  
		foreach v of varlist s3q11 s3q12 s3q13 {
			replace `v' = `v' / s3q9a_ha if s3q9a_ha != .
		}
		*/
		
		ge hafullprod = s3q12*s3q9a_ha
		label variable hafullprod "cocoa land in full production, ha."
	

		*  Tree types cleanup:
		label define cocoatypes ///
			0 "No cocoa is currently grown on this farm" ///
			1 "Tettah Quashie (local)" ///
			2 "Amazon" ///
			3 "Hybrid" ///
			, modify
		ge amazon = 0
		ge tq = 0
		ge hybrid = 0
		foreach v in amazon tq hybrid {
			label variable `v' "share of land planted with `v'"
		}
	
		foreach v in s3q14a s3q14b s3q14c {
			replace tq = tq + 1/3 if `v'==1
			replace amazon = amazon + 1/3 if `v'==2
			replace hybrid = hybrid + 1/3 if `v'==3
		}
		ge hybridsland = s3q9a_ha * hybrid / (hybrid + tq + amazon)
		label variable hybridsland "land planted with hybrid trees, ha."
	
	
		*  collapsing to farmer level
		local hafullprod : variable label hafullprod
		local s3q9a_ha : variable label s3q9a_ha
		local s3q1a_ha : variable label s3q1a_ha
	
	
		*  Collapsing 
	ge plotcount = 1
	
		collapse (sum) plotcount hafullprod hybridsland cocoaland=s3q9a_ha totland=s3q1a_ha totprice=s3q5, by(s0far)
		ge hybridlandshare =hybridsland/cocoaland
		label variable hybridlandshare "actual share hybrid trees"
		ge priceha=totprice/totland
		label variable priceha "land price, c/ha"
		ge lnhaprod = ln(hafullprod)
	
	
	* 4.2 Household level data (outputs inputs)
	
	
	ge year = 2002
	sort s0far year
	merge s0far using "$gcfs02\gcfs02" ///
		, _merge(_m02plots) ///
		keep( s0rgn s0vil kg_cocoa fert_yn fertilizer_50kg s4bq1b spraymch hh_days hired_days paid_days nnoboa_days )
	sort s0far year
	rename s4bq1b insecticide
	
	
	
	*  merging 2002 with 2004 and 2006 data
	
	
	merge s0far year using "$data\panel.dta", _merge(_m02)
	sort s0far year
}



****************************************************************************
/*  FINAL DATA PREPARATION */
****************************************************************************

	*  Variable labels
		label variable s0far "farmer ID"
		label variable s0vil "village ID"
		label variable year "year of survey"
		label variable plotcount "number of cocoa plots cultivated"
		label variable hafullprod "area under cocoa in full production (excluding very young and very old), ha."
		label variable cocoaland "area cultivated with cocoa, ha."
		label variable totland "total cultivated area, all crops, ha."
		label variable totprice "self-reported value of all cocoa plots"

	*  5.1   Analytical variables of interest
	
		*  Output	
			ge lncocoa = ln(kg_cocoa)
			label variable lncocoa "ln cocoa, kg."
			ge yield = kg_cocoa / cocoaland
			label variable yield "yield (kg/ha)"
	
		*  Labor
			ge labordays = hh_days + hired_days
			label variable labordays "total labor days"
			ge lnlabordays = ln(hh_days + hired_days)
			label variable lnlabordays "ln total labor days"
			ge frachhdays = hh_days / (hh_days + hired_days)
			label variable frachhdays "fraction household of total labor days"
	
		*  Farm sizes
			ge lnha = ln(cocoaland)
			label variable lnha "ln total cocoa land, ha."
		
	
	*  5.2  Time setting the data
	
		ge w5 = (year == 2010)
		label variable w5 "2009/10 cocoa season"
		ge w4 = (year==2008)
		label variable w4 "2007/08 cocoa season"
		ge w3 = (year==2006)
		label variable w3 "2005/06 cocoa season"
		ge w2 = (year == 2004)
		label variable w2 "2003/04 cocoa season"
		ge wave = (year-2000)/2
		label variable wave "survey wave"
		sort s0far wave
		tsset s0far wave
	
	*  Cleaning villages
	
	*  some problems in regions need to be sorted out first
	replace s0rgn = 2 if s0vil == 10
	replace s0rgn = 2 if s0vil == 14
	replace s0rgn = 2 if s0vil == 16
	replace s0rgn = 2 if s0vil == 17
	replace s0rgn = 3 if s0vil == 19
	replace s0rgn = 2 if s0vil == 29
	
	levelsof s0vil if s0vil < 100 , local(vils) clean
	tokenize `vils'
	local V=wordcount("`vils'")
	forvalues v=1/`V' {
		qui tab s0rgn if s0vil == ``v''
		if `r(r)' > 1 {
			di "``v'':"
			tab s0rgn if s0vil == ``v''
		}
	
	}
	
	replace s0vil = s0rgn * 100 + s0vil if s0vil < 100 
	#delimit ;
	label define villages
	     101 "Nobewam"
         102 "Konongo-Odumase"
         103 "Akutuase"
         104 "Amanona-Barniekrom"
         105 "Mponua-Nyinahin"
         107 "Twerebuana"
         108 "Kyebi"
         128 "Nkakwum"
         151 "Aponaponso"
         152 "Krofofrom"
         153 "Yaw Sarfo"
         210 "Nsuta-Sreso"
         212 "Aboabo No. 4"
         214 "Akwaboa No. 2"
         215 "Sankore"
         216 "Bogyampa"
         217 "Nkasem"
         229 "Anum"
         251 "Asukese Mim"
         252 "Bediako"
         253 "Camp Junction"
         254 "Gambia 1"
         255 "Kwaoprete"
         318 "Bosomoiso"
         319 "Wiawso Town"
         320 "Mansokrom"
         321 "Kojo Aba"
         322 "Nkatieso"
         323 "Acquai Allah"
         324 "Aniamoate"
         325 "Ayaaboi"
         326 "Amanase"
         327 "Anyinabrim"
         328 "New Kumasi"
         351 "Asantekrom"
         352 "Beposo A"
         353 "Bokaso"
         354 "Asesansu"
         376 "Gravel Yard"
         377 "Prestea Nkwanta"
         378 "Tie Nyame Asem"
         379 "Adubrim"
         380 "Mfanteman Opokukrom"
         381 "Neneso Nsuta Krobo"
         399 "Baanaso"
         401 "Adofo Camp"
         402 "Asensuho Shed"
         403 "Kwaku Panyin"
         501 "Gyewani Nkwanta"
         502 "Kadewaso"
         503 "W. Amanfrom"
         , modify ;
    #delimit cr
    label values s0vil villages
	
	* then: any individuals misfiled so that they end up in 2 villages?
		sort s0far year
		replace s0vil = s0vil[_n-1] if s0vil == . & s0far[_n-1]==s0far
		replace s0vil =  322 if s0far == 322284 & year == 2006 & s0vil == 217
		replace s0vil =  322 if s0far == 322289 & year == 2006 & s0vil == 217
		replace s0far = 326483 if s0far == 324430 & s0nam == "Philemon Kyei" // apparent misfile.  consequent data overwrite?  watch subfiles...
		replace s0vil =  326 if s0far == 326490 & year == 2008 & s0vil == 324
		replace s0vil = 328 if s0vil == 330 & real(substr(string(s0far),1,3)) ==328 & year == 2006
	* and any whose village does not match the id?
		replace s0vil = real(substr(string(s0far),1,3)) if s0vil == . & (s0far == 108802 | s0far == 237400 | s0far == 212801 )
		
		replace s0far = 321456 if s0rgn == 3 & s0far == 123456
		replace s0far = 321835 if s0rgn == 3 & s0far == 123835
		replace s0far = 321931 if s0rgn == 3 & s0far == 123931
		replace s0far = 321932 if s0rgn == 3 & s0far == 123932
		replace s0far = 321933 if s0rgn == 3 & s0far == 123933 
		replace s0far = 321934 if s0rgn == 3 & s0far == 123934
		
		*  replace s0far = real("321" + substr(string(s0far,4,.))) if s0rgn == 3 & ( s0far == 123456 | s0far == 123835 | s0far == 123931 | s0far == 123932 | s0far == 123933 | s0far == 123934)

		replace s0vil = 377 if s0far == 377001 & s0nam == "Prestea Nkwanta"
		replace s0vil = 381 if s0far == 381006 & s0rgn == 3
		
		drop if s0far == 0
		drop if s0far == 237400 // questionable.  cannot be matched to village.

		
		ge v2 = real(substr(string(s0far),1,3))
		ge mismatch = (v2!=s0vil)
		egen anymismatch = max(mismatch), by(s0far) 
				
		egen tag = tag(s0far s0vil) , missing
		egen mult = sum(tag), by(s0far)
		sort s0far year
		order s0far year s0vil s0nam mult
		count if mult>1
		tab mismatch mult 
		
		browse if mult > 1
		browse if anymisma
		pause
		drop v2 tag mult mismat anymis
		
		*  final cleanup of panel villages:  drop any individuals now discovered to be resident in CAA villages
			drop if s0vil == 377 | s0far == 381
			
		ge sample = "Oxford Panel"
		order sample s0far s0nam s0rgn s0vil
		drop _* panelmerge
		
		
	
	
	
	*  Anonymizing
		drop s0nam
		label values s0vil 
		label define village , replace


	save "$data\panel_apr13.dta", replace
	if ( "$dodropbox" == "on" ) save "$dropdata\panel.dta", replace
	
exit	
	*  Variables constructed for Gbade:  
	
		*  Number of LBCs in the village
			split s8bq1, gen(lbc_) parse(";")	
			forvalues i = 1/10 {
				ge islbc_`i' = 1 if lbc_`i' != ""
				replace islbc_`i' = 0 if lbc_`i' == ""
			}
			egen nlbcs = rowtotal(islbc_*)
			egen maxnlbcs = max(nlbcs) if wave == 5 , by(s0vil wave)
			egen meanlbcs = mean(nlbcs) if wave == 5, by(s0vil wave)
			drop islbc_*
	
			ge certinfo = 1 if certify_heard != "" & certify_heard != "None" & wave == 5
			replace certinfo = 0 if certify_heard == "None" & wave == 5
	
		*  Merging LBC sales relationships
			save "$public\gbade\panel_gbade.dta", replace
		

			
			
			
		*  Final save
	outsheet using $public\gbade\panel.csv, comma replace
	saveold "$public\gbade\panel_gbade.dta", replace
